@@ -58,6 +58,12 @@ class ApiDeviceHardware:
     SHUTTER = "SHUTTER"
     VIRTUAL = "VIRTUAL"
     TIMED_POWER_SWITCH = "TIMED_POWER_SWITCH"
+    THERMOSTAT = "THERMOSTAT"
+    SOCKET_IR = "SOCKET_IR"
+    SOMFY = "SOMFY"
+    IRRIGATION = "IRRIGATION"
+    REPEATER = "REPEATER"
+    GROUP_SWITCH = "GROUP_SWITCH"
 
 
 class ApiDeviceType:
